@@ -1,7 +1,7 @@
 from django import forms
 
 
-class PasswordlessLoginForm(forms.Form):
+class PasswordlessRequestForm(forms.Form):
     email = forms.EmailField()
 
 
